# Basic Geometry

The basic geometry commands create geometric entities that are referenced by Part objects, Instance objects, and GeometrySet objects.

## Other Classes

```{eval-rst}

.. toggle::

    .. autoclass:: abaqus.BasicGeometry.Cell.Cell
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.BasicGeometry.CellArray.CellArray
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.BasicGeometry.Edge.Edge
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.BasicGeometry.EdgeArray.EdgeArray
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.BasicGeometry.Face.Face
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.BasicGeometry.FaceArray.FaceArray
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.BasicGeometry.IgnoredEdge.IgnoredEdge
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.BasicGeometry.IgnoredEdgeArray.IgnoredEdgeArray
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.BasicGeometry.IgnoredVertex.IgnoredVertex
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.BasicGeometry.IgnoredVertexArray.IgnoredVertexArray
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.BasicGeometry.InterestingPoint.InterestingPoint
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.BasicGeometry.ModelDot.ModelDot
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.BasicGeometry.ModelDotArray.ModelDotArray
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.BasicGeometry.ReferencePoint.ReferencePoint
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.BasicGeometry.ReferencePointArray.ReferencePointArray
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.BasicGeometry.ReferencePoints.ReferencePoints
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.BasicGeometry.Transform.Transform
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.BasicGeometry.Vertex.Vertex
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.BasicGeometry.VertexArray.VertexArray
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::
```
